Coinbase
========

.. image:: https://pypip.in/version/coinbase/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/coinbase

.. image:: https://img.shields.io/travis/coinbase/coinbase-python/master.svg?style=flat
    :target: https://travis-ci.org/coinbase/coinbase-python

.. image:: https://pypip.in/download/coinbase/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/coinbase/

.. image:: https://pypip.in/wheel/blackhole/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/coinbase/

.. image:: https://pypip.in/py_versions/coinbase/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/coinbase/

.. image:: https://pypip.in/license/blackhole/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/coinbase/

The official Python library for the `Coinbase API
<https://developers.coinbase.com/api>`_.


Features
--------

- Near-100% test coverage.
- Support for both `API Key + Secret
  <https://coinbase.com/docs/api/authentication#hmac>`_ and `OAuth 2
  <https://coinbase.com/docs/api/authentication#oauth2>`_ authentication.
- Convenient methods for making calls to the API - packs JSON for you!
- Automatic parsing of API responses into relevant Python objects.
- All objects have tab-completable methods and attributes when using
  `IPython <http://ipython.org>`_.

For more information, please `visit the Github repository
<https://github.com/coinbase/coinbase-python>`_.

Note: this package used to refer to the unofficial ``coinbase_python`` library
maintained by `George Sibble <http://onepercentbreadsticks.com/>`_. You can
find that package `on Github <https://github.com/sibblegp/coinbase_python>`_.
